import Image from 'next/image';
import { ChangeEvent, useState } from 'react';
import lensIcon from '@/assets/vectors/icons/lens.svg';

export const SearchBar = (): JSX.Element => {
  const [searchValue, setSearchValue] = useState<string>('');

  const onSearchChange = (event: ChangeEvent<HTMLInputElement>): void => {
    setSearchValue(event.target.value);
  };

  return (
    <div className="relative" data-testid="search-bar">
      <input
        value={searchValue}
        name="search-input"
        aria-label="search-input"
        data-testid="search-input"
        onChange={onSearchChange}
        className="bg-cultured r-[64px] w-72 rounded-[64px] py-2.5 px-4 text-xs outline-none border border-transparent focus:border-greyscale-600 hover:border-greyscale-600  font-medium text-font-400"
      />
      <Image
        src={lensIcon}
        alt="lens icon"
        height={16}
        width={16}
        className="absolute right-4 top-2.5"
      />
    </div>
  );
};
